@@ -4,14 +4,18 @@ from RG.R2 import *
 
 from RG.PCA import *
 from RG.PLS import *
+from RG.VIP import *
 from RG.mbPLS import *
 from RG.cPCA import *
 from RG.LDA import *
 from RG.PCA_ellipse import *
+from RG.ICA import *
 
 
 from RG.colorspectra import *
-from RG.axabline import *
+from RG.axaline import *
+from RG.lags import *
+from RG.DTW import *
 
 from RG.center import *
 from RG.autoscale import *
